@@ -65,7 +65,7 @@ def main_logic():
             uuid = 'honeypotslogger' + '_' + 'main' + '_' + str(uuid4())[:8]
             logs = setup_logger(uuid, ARGV.config, True)
             if isinstance(honeypots, dict):
-                for honeypot in honeypots.items():
+                for honeypot in honeypots:
                     if "port" in honeypots[honeypot]:
                         for _honeypot in all_servers:
                             if 'q{}server'.format(honeypot).lower() == _honeypot.lower():
@@ -78,7 +78,7 @@ def main_logic():
                                 x = locals()[_honeypot](config=ARGV.config)
                                 x.run_server(process=True)
                                 temp_honeypots.append(x)
-            if isinstance(honeypots, list):
+            elif isinstance(honeypots, list):
                 for server in honeypots.split(','):
                     if ":" in server:
                         for honeypot in all_servers:
